/*
 *     This file is part of the RESULT PUBLISHER API plugin for Squash TM (henix-tm-api-rest-automation-result-publisher) project.
 *     Copyright (C) 2020 - 2021 Henix, henix.fr - All Rights Reserved
 *
 *     Unauthorized copying of this file, via any medium is strictly prohibited
 *     Proprietary and confidential
 *
 * 	 (C)Henix. Tous droits réservés.
 *
 * 	Avertissement : ce programme est protégé par la loi relative au droit d'auteur et par les conventions internationales. Toute reproduction ou distribution partielle ou totale du logiciel, par quelque moyen que ce soit, est strictement interdite.
 */
require(['common'], function () {
    require(["jquery", "app/pubsub", "app/ws/squashtm.notification", "underscore", "squash.configmanager",
            "squash.basicwidgets", "squash.translator", "jquery.switchButton"],

        function ($, pubsub, notification, _, confman, basic, translator) {

            var pageconf = squashtm.plugin.resultpublisher.pageconf;

            // *********** Prefiling the ajax with the required token (Squash 1.18+) ***********

            if ($("meta[name='_csrf']").length > 0){
                $.ajaxPrefilter(function (options, originalOptions, jqXHR) {
                    var token = $("meta[name='_csrf']").attr("content");
                    var header = $("meta[name='_csrf_header']").attr("content");
                    jqXHR.setRequestHeader(header, token);
                });
            }

            // ********* events subscription *********************

            pubsub.subscribe("resultpublisher.configuration.automatedexecutiontype", configureSwitch);
            pubsub.subscribe("resultpublisher.configuration.complete", complete);


            function configureSwitch(){
                var switchdiv = $("#automated-execution-type-switch-div");

                var chk = $("<input>", {
                    'type' : 'checkbox',
                    'id' : 'automated-execution-type-switch'
                });

                if (pageconf.configuration.automatedExecutionType === "COMPLETE"){
                    chk.prop('checked', true);
                }

                switchdiv.empty().append(chk);

                chk.switchButton({
                    on_label : translator.get('squash.tm.plugin.resultpublisher.configuration.execution.complete.label'),
                    off_label : translator.get('squash.tm.plugin.resultpublisher.configuration.execution.light.label')
                });

                chk.on('change', switchExecutionType);
            }
            // ********* final initialization ***********
            function complete() {

                basic.init();
            }
            // ******** common code *********************

            function baseUrl() {
                var pageconf = squashtm.plugin.resultpublisher.pageconf;
                return squashtm.app.contextRoot + 'resultpublisher/project/' + pageconf.projectId + '/configuration';
            }

            function switchExecutionType(evt){
                hideMessage();

                var checkbox = $(evt.currentTarget);
                var checked = checkbox[0].checked;

                var configurationForProject = {
                    automatedExecutionType: checked ? "COMPLETE" : "LIGHT"
                };

                $.ajax({
                    url: baseUrl(),
                    type: 'POST',
                    contentType: 'application/json',
                    data: JSON.stringify(configurationForProject)
                }).success(function(){
                    var msgSuccessSave=translator.get("squash.tm.plugin.resultpublisher.configuration.save.success");
                    showMessage(msgSuccessSave, 'green');
                    pageconf.configuration = configurationForProject;
                }).fail(function(){
                    var msgFailureSave=translator.get("squash.tm.plugin.resultpublisher.configuration.save.failure");
                    showMessage(msgFailureSave, 'red');
                });
            }

            function showMessage(message, color){
                $('#div-msg').show();
                $('#msg').text(message);
                $('#msg').css('color', color);
            }

            function hideMessage(){

                $('#div-msg').hide();
            }
            /*fin*/
        })
});
